Learn R Programming

sodavis (version 1.2)

pumadyn: Pumadyn dataset

Description

This is a dataset synthetically generated from a realistic simulation of the dynamics of a Unimation Puma 560 robot arm.

Usage

data(pumadyn)

Arguments

Format

Response variable vector and design matrix on 4499 in-sample and 3693 out-sample observations for 32 predictor variables.

References

Corke, P. I. (1996). A Robotics Toolbox for MATLAB. IEEE Robotics and Automation Magazine, 3 (1): 24-32.