S-SODA assumes within each slice the X vector follow multivariate normal distribution. This function estimates the mean vector and covariance matrix of X for each slice.
s_soda_model(x, y, H = 10)The design matrix, of dimensions n * p, without an intercept. Each row is an observation vector.
The response vector of dimension n * 1.
The number of slices.
Slice index.
Proportion of samples in each slice.
Length of each slice (max - min response).
Mean vector of covariates in each slice.
Covariance matrix of covariates in each slice.